@@ -1,5 +1,5 @@
 """
-Rivulet - Streaming SQL Join Engine
+Streaming SQL Join Engine
 
 A lightweight SQL execution engine that processes queries row-by-row
 without loading full tables into memory.
@@ -16,7 +16,7 @@ from .db_connector import (
     create_table_source
 )
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __all__ = [
     "Engine",
     "PostgreSQLPool",
